pub struct Logger { /* private fields */ }
An implementation of the log::Log trait for Fastly Compute@Edge.
Create and initialize a Logger by using the builder returned by Logger::builder().
Formats the value using the given formatter.
Read more
Determines if a log message with the specified metadata would be
logged.
Read more
Flushes any buffered records.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.